Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7784)

Unified Diff: chrome/browser/task_manager/sampling/task_manager_impl.h

Issue 2905403002: plumb network upload into the task manager (Closed)
Patch Set: fixed comments Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/task_manager/sampling/task_manager_impl.h
diff --git a/chrome/browser/task_manager/sampling/task_manager_impl.h b/chrome/browser/task_manager/sampling/task_manager_impl.h
index b483494326c315aa64dd414f5d77358422e6d75f..5e1ef98f6cfa460acf1c7530dd90f2521321a3cd 100644
--- a/chrome/browser/task_manager/sampling/task_manager_impl.h
+++ b/chrome/browser/task_manager/sampling/task_manager_impl.h
@@ -74,7 +74,9 @@ class TaskManagerImpl : public TaskManagerInterface,
base::TerminationStatus* out_status,
int* out_error_code) const override;
int64_t GetNetworkUsage(TaskId task_id) const override;
+ int64_t GetCumulativeNetworkUsage(TaskId task_id) const override;
int64_t GetProcessTotalNetworkUsage(TaskId task_id) const override;
+ int64_t GetCumulativeProcessTotalNetworkUsage(TaskId task_id) const override;
int64_t GetSqliteMemoryUsed(TaskId task_id) const override;
bool GetV8Memory(TaskId task_id,
int64_t* allocated,
@@ -94,9 +96,11 @@ class TaskManagerImpl : public TaskManagerInterface,
void TaskRemoved(Task* task) override;
void TaskUnresponsive(Task* task) override;
- // The notification method on the UI thread when multiple bytes are read
- // from URLRequests. This will be called by the |io_thread_helper_|
- static void OnMultipleBytesReadUI(std::vector<BytesReadParam>* params);
+ // The notification method on the UI thread when multiple bytes are
+ // transferred from URLRequests. This will be called by the
+ // |io_thread_helper_|
+ static void OnMultipleBytesTransferredUI(
+ std::vector<BytesTransferredParam>* params);
private:
friend struct base::LazyInstanceTraitsBase<TaskManagerImpl>;
@@ -119,7 +123,7 @@ class TaskManagerImpl : public TaskManagerInterface,
// false otherwise, at which point the caller must explicitly match these
// bytes to the browser process by calling this method again with
// |param.origin_pid = 0| and |param.child_id = param.route_id = -1|.
- bool UpdateTasksWithBytesRead(const BytesReadParam& param);
+ bool UpdateTasksWithBytesTransferred(const BytesTransferredParam& param);
TaskGroup* GetTaskGroupByTaskId(TaskId task_id) const;
Task* GetTaskByTaskId(TaskId task_id) const;
« no previous file with comments | « chrome/browser/task_manager/sampling/task_group_unittest.cc ('k') | chrome/browser/task_manager/sampling/task_manager_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698